==> auto-ui-2.4.55.tgz: package/es/popup/index.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import { createPortal } from 'react-dom';
import Modal from '../modal/index';
import './style/index.scss';
var Popup = /** @class */ (function (_super) {
    __extends(Popup, _super);
    function Popup(props) {
        var _this = _super.call(this, props) || this;
        _this.div = void 0;
        // 在当前节点中展示
        if (props.local) {
            return _this;
        }
        _this.div = document.createElement('div');
        _this.div.classList.add('_x_popup_');
        document.body.appendChild(_this.div);
        return _this;
    }
    Popup.prototype.componentWillUnmount = function () {
        if (this.div) {
            document.body.removeChild(this.div);
        }
    };
    Popup.prototype.content = function () {
        var _a = this.props, className = _a.className, top = _a.top, _b = _a.direction, direction = _b === void 0 ? 'top' : _b, onMaskClick = _a.onMaskClick, height = _a.height, width = _a.width, visible = _a.visible, _c = _a.keepalive, keepalive = _c === void 0 ? true : _c, noPadding = _a.noPadding, smoothBorder = _a.smoothBorder, children = _a.children, otherProps = __rest(_a, ["className", "top", "direction", "onMaskClick", "height", "width", "visible", "keepalive", "noPadding", "smoothBorder", "children"]);
        if (top) {
            console.warn('auto-ui: Popup组件的top属性请使用direction属性来代替');
            direction = 'bottom';
        }
        var composeClassName = cn('x-popup', {
            'x-popup--smooth-border': smoothBorder,
        }, "x-popup--" + direction, className);
        var composeChildren = [];
        if (Array.isArray(children)) {
            composeChildren.push.apply(composeChildren, children);
        }
        else {
            composeChildren.push(children);
        }
        var hasScrollChildren = false;
        composeChildren.forEach(function (res) {
            if (res.type === Scroller && !hasScrollChildren) {
                hasScrollChildren = true;
            }
        });
        var innercss = cn('x-popup__inner', {
            'x-popup--no-scroll': hasScrollChildren,
            'x-popup--no-padding': noPadding,
        });
        // DOM没有local这个属性，需要删除
        delete otherProps.local;
        return (React.createElement(Modal, __assign({}, otherProps, { visible: visible, keepalive: keepalive, height: height, width: width, onMaskClick: onMaskClick, className: composeClassName }),
            React.createElement("div", { className: innercss }, children)));
    };
    Popup.prototype.render = function () {
        if (this.div) {
            return createPortal(this.content(), this.div);
        }
        if (this.props.local) {
            return this.content();
        }
        return null;
    };
    return Popup;
}(React.PureComponent));
var Scroller = function (props) {
    var className = props.className, children = props.children, otherProps = __rest(props, ["className", "children"]);
    var composeClassName = cn('x-popup__scroller', className);
    return (React.createElement("div", __assign({}, otherProps, { className: composeClassName }),
        React.createElement("div", { className: "x-popup__inscroller" }, children)));
};
Popup.Scroller = Scroller;
export default Popup;

==> auto-ui-2.4.63.tgz: package/es/popup/index.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import { createPortal } from 'react-dom';
import Modal from '../modal/index';
import './style/index.scss';
var Popup = /** @class */ (function (_super) {
    __extends(Popup, _super);
    function Popup(props) {
        var _this = _super.call(this, props) || this;
        _this.div = void 0;
        // 在当前节点中展示
        if (props.local) {
            return _this;
        }
        _this.div = document.createElement('div');
        _this.div.classList.add('_x_popup_');
        document.body.appendChild(_this.div);
        return _this;
    }
    Popup.prototype.componentWillUnmount = function () {
        if (this.div) {
            document.body.removeChild(this.div);
        }
    };
    Popup.prototype.content = function () {
        var _a = this.props, className = _a.className, top = _a.top, _b = _a.direction, direction = _b === void 0 ? 'top' : _b, onMaskClick = _a.onMaskClick, height = _a.height, width = _a.width, visible = _a.visible, _c = _a.keepalive, keepalive = _c === void 0 ? true : _c, noPadding = _a.noPadding, smoothBorder = _a.smoothBorder, children = _a.children, otherProps = __rest(_a, ["className", "top", "direction", "onMaskClick", "height", "width", "visible", "keepalive", "noPadding", "smoothBorder", "children"]);
        if (top) {
            console.warn('auto-ui: Popup组件的top属性请使用direction属性来代替');
            direction = 'bottom';
        }
        var composeClassName = cn('x-popup', {
            'x-popup--smooth-border': smoothBorder,
        }, "x-popup--" + direction, className);
        var composeChildren = [];
        if (Array.isArray(children)) {
            composeChildren.push.apply(composeChildren, children);
        }
        else {
            composeChildren.push(children);
        }
        var hasScrollChildren = false;
        composeChildren.forEach(function (res) {
            if (res.type === Scroller && !hasScrollChildren) {
                hasScrollChildren = true;
            }
        });
        var innercss = cn('x-popup__inner', {
            'x-popup--no-scroll': hasScrollChildren,
            'x-popup--no-padding': noPadding,
        });
        // DOM没有local这个属性，需要删除
        delete otherProps.local;
        return (React.createElement(Modal, __assign({}, otherProps, { visible: visible, keepalive: keepalive, height: height, width: width, onMaskClick: onMaskClick, className: composeClassName }),
            React.createElement("div", { className: innercss }, children)));
    };
    Popup.prototype.render = function () {
        if (this.div) {
            return createPortal(this.content(), this.div);
        }
        if (this.props.local) {
            return this.content();
        }
        return null;
    };
    return Popup;
}(React.PureComponent));
var Scroller = function (props) {
    var className = props.className, children = props.children, otherProps = __rest(props, ["className", "children"]);
    var composeClassName = cn('x-popup__scroller', className);
    return (React.createElement("div", __assign({}, otherProps, { className: composeClassName }),
        React.createElement("div", { className: "x-popup__inscroller" }, children)));
};
Popup.Scroller = Scroller;
export default Popup;
